@@ -302,27 +302,29 @@ class objearth():
     
     @staticmethod
     def leafwood():
-        RGB1  = (0.30588235, 0.05490196, 0.05490196)
-        RGB2  = (0.39215686, 0.09803922, 0.07843137)
-        RGB3  = (0.43921569, 0.18431373, 0.00392157)
-        RGB4  = (0.54901961, 0.2745098 , 0.05882353)
-        RGB5  = (0.61960784, 0.30588235, 0.02745098)
-        RGB6  = (0.70980392, 0.40784314, 0.0627451)
-        RGB8  = (0.85098039, 0.51764706, 0.04705882)
-        RGB7  = (0.8627451 , 0.50980392, 0.05490196)
-        RGB9  = (0.85882353, 0.63529412, 0.05490196)
-        RGB10 = (0.91764706, 0.69019608, 0.01568627)
-        RGB11 = (0.87058824, 0.8       , 0.05098039)
-        RGB12 = (0.89019608, 0.8745098 , 0.07058824)
-        RGB13 = (0.92156863, 0.91764706, 0.09019608)
-        RGB14 = (0.81176471, 0.85882353, 0.2745098 )
-        RGB15 = (0.56862745, 0.68627451, 0.21960784)
-        RGB16 = (0.56078431, 0.69803922, 0.25882353)
-        RGB17 = (0.52156863, 0.6627451 , 0.21960784)
-        RGB18 = (0.35686275, 0.49803922, 0.11764706)
-        RGB19 = (0.23529412, 0.46666667, 0.05490196)
-        RGB20 = (0.16078431, 0.36862745, 0.04313725)
-        RGB21 = (0.09411765, 0.35294118, 0.01176471)
+        #https://mycolor.space/gradient?ori=to+right+top&hex=%2385A938&hex2=%233C770E&sub=1
+        #https://imagecolorpicker.com/en
+        RGB1   = (0.30588235, 0.05490196, 0.05490196)   #RGB(78,14,14)          
+        RGB2   = (0.39215686, 0.09803922, 0.07843137)   #RGB(100,25,20)
+        RGB3   = (0.43921569, 0.18431373, 0.00392157)   #RGB(112,47,1)
+        RGB4   = (0.50980392, 0.23529412, 0.05098039)   #RGB(130,60,13)
+        RGB5   = (0.54901961, 0.2745098 , 0.05882353)   #RGB(140,70,15)
+        RGB6   = (0.61960784, 0.30588235, 0.02745098)   #RGB(158,78,7)
+        RGB7   = (0.70980392, 0.40784314, 0.0627451 )   #RGB(181,104,16) 
+        RGB8   = (0.79607843, 0.49019608, 0.16470588)   #RGB(203, 125, 42)
+        RGB9   = (0.85490196, 0.58823529, 0.04705882)   #RGB(218,150,12)
+        RGB10  = (0.85882353, 0.63529412, 0.05490196)   #RGB(219,162,14)
+        RGB11  = (0.88235294, 0.7254902 , 0.01568627)   #RGB(225,185,4)
+        RGB12  = (0.87058824, 0.8       , 0.05098039)   #RGB(222,204,13)
+        RGB13  = (0.89019608, 0.8745098 , 0.07058824)   #RGB(227,223,18)
+        RGB14  = (0.92156863, 0.91764706, 0.09019608)   #RGB(235,234,23)
+        RGB15  = (0.81176471, 0.85882353, 0.2745098 )   #RGB(207,219,70)
+        RGB16  = (0.68627451, 0.77647059, 0.26666667)   #RGB(175,198,68)
+        RGB17  = (0.56078431, 0.69803922, 0.25882353)   #RGB(143,178,66)
+        RGB18  = (0.52156863, 0.6627451 , 0.21960784)   #RGB(133,169,56)
+        RGB19  = (0.38039216, 0.56470588, 0.14117647)   #RGB(97, 144, 36)
+        RGB20  = (0.23529412, 0.46666667, 0.05490196)   #RGB(60,119,14)
+        RGB21  = (0.16078431, 0.36862745, 0.04313725)   #RGB(41,94,11)
         cdict = {
             'red':  ((1  / 20 * 0,  (RGB1[0])  ,(RGB1[0])),
                     (1  / 20 * 1,  (RGB2[0])  ,(RGB2[0])),
